@@ -458,7 +458,10 @@ def get_all_ads(client,customer_id):
     ad_group_ad.ad.final_urls,
     ad_group_ad.ad.responsive_search_ad.path1,
     ad_group_ad.ad.responsive_search_ad.path2,
-    ad_group_ad.status
+    ad_group_ad.status,
+    ad_group_ad.ad_strength,
+    metrics.impressions,
+    metrics.conversions    
     FROM ad_group_ad
     WHERE ad_group_ad.ad.type = RESPONSIVE_SEARCH_AD AND campaign.status IN ('ENABLED', 'PAUSED')
     AND ad_group.status IN ('ENABLED', 'PAUSED')
@@ -469,6 +472,10 @@ def get_all_ads(client,customer_id):
         'campaign_id': list(),
         'adgroup_status':list(),
         'campaign_status':list(),
+        'adgroup_ad_strength':list(),
+        'adgroup_ad_status':list(),
+        'metrics_impressions':list(),
+        'metrics_conversions':list(),
         'adgroup_ad_id': list(),
         'headline_keywords': list(),
         'ad_description': list(),
@@ -502,6 +509,10 @@ def get_all_ads(client,customer_id):
             df_dict['campaign_id'].append(campaign.id)
             df_dict['campaign_status'].append(campaign.status.name)
             df_dict['adgroup_status'].append(adgroup.status.name)
+            df_dict['adgroup_ad_status'].append(adgroup_ad.status.name)
+            df_dict['metrics_impressions'].append(row.metrics.impressions)
+            df_dict['metrics_conversions'].append(row.metrics.conversions)
+            df_dict['adgroup_ad_strength'].append(adgroup_ad.ad_strength.name)
             df_dict['adgroup_ad_id'].append(adgroup_ad.ad.id)
             df_dict['headline_keywords'].append(temp)
             df_dict['ad_description'].append(temp2)
@@ -572,7 +583,7 @@ def get_ads(client,customer_id,ad_group_id):
     df = pd.DataFrame.from_dict(df_dict)
     return df
 
-def create_ad(client, customer_id, ad_group_id, final_url, headlines, descriptions, path1, path2):
+def create_ad(client, customer_id, ad_group_id, final_url, headlines, descriptions, path1, path2,enable=False):
 
     def _create_ad_text_asset(client, text, pinned_field=None):
         """Create an AdTextAsset."""
@@ -589,7 +600,10 @@ def create_ad(client, customer_id, ad_group_id, final_url, headlines, descriptio
     # Create the ad group ad.
     ad_group_ad_operation = client.get_type("AdGroupAdOperation")
     ad_group_ad = ad_group_ad_operation.create
-    ad_group_ad.status = client.enums.AdGroupAdStatusEnum.PAUSED
+    if enable:
+        ad_group_ad.status = client.enums.AdGroupAdStatusEnum.ENABLED
+    else:
+        ad_group_ad.status = client.enums.AdGroupAdStatusEnum.PAUSED
     ad_group_ad.ad_group = ad_group_service.ad_group_path(
         customer_id, ad_group_id
     )
@@ -641,7 +655,7 @@ def update_adgroup(client,customer_id, ad_group_id, **kwargs):
             if stat == 'PAUSED':
                 ad_group.status = client.enums.AdGroupStatusEnum.PAUSED
             elif stat == 'ENABLED':
-                ad_group.status = client.enums.AdGroupStatusEnum.ENABLED
+                ad_group.status = client.enums.AdGroupStatusEnum.AdGroupAdStatusEnum
             elif stat == 'UNSPECIFIED':
                 ad_group.status = client.enums.AdGroupStatusEnum.UNSPECIFIED
         if 'cpc_bid_micro_amount' in kwargs:
@@ -770,6 +784,20 @@ def remove_keyword(client, customer_id, ad_group_id, criterion_id):
 
     print(f"Removed keyword {agc_response.results[0].resource_name}.")
 
+def remove_ad(client, customer_id, ad_group_id, criterion_id):
+    ad_group_ad_service = client.get_service("AdGroupAdService")
+    ad_group_ad_operation = client.get_type("AdGroupAdOperation")
+
+    resource_name = ad_group_ad_service.ad_group_ad_path(
+        customer_id, ad_group_id, criterion_id
+    )
+    ad_group_ad_operation.remove = resource_name
+
+    ad_group_ad_response = ad_group_ad_service.mutate_ad_group_ads(
+        customer_id=customer_id, operations=[ad_group_ad_operation]
+    )
+
+    print(f"Removed ad {ad_group_ad_response.results[0].resource_name}.")
 
 def get_search_term_report(client, customer_id,start_date='2022-01-01', end_date='2022-01-10'):
     df_dict = {
