@@ -30,11 +30,13 @@ df = pd.read_csv(df_path)
 
 print("Getting existing keywords")
 df_existing = get_existing_keywords(googleads_client,customer_id)
-df_existing = pd.read_csv(save_path+'/df_existing.csv')
+# df_existing = pd.read_csv(save_path+'/df_existing.csv')
 keywords_to_remove = df_existing.query("(camp_status == 'ENABLED') & \
                                         (adgroup_status == 'ENABLED') &\
                                         (keyword_status == 'ENABLED')")['keyword_name'].unique().tolist()
 df = df[~df["Keywords"].isin(keywords_to_remove)] # if campaign in enabled and keyword clash remove it.
+df['keyword_length'] = df['Keywords'].apply(lambda x:len(x))
+df = df[df['keyword_length']<=80]
 
 #First pass of filters
 print("Applying filters on the data")
@@ -53,29 +55,31 @@ task_params = {
     # 'people_also_ask': ['title'],
 }
 
-print("Getting meta titles from SERP")
+print("Getting Descriptions")
 seed_keywords = df["Keywords2"].unique().tolist()
 for keyword in seed_keywords:
     print(keyword)
     response = make_live_request(keyword,email,api_key,depth=5)
-    results = get_results(response,tasks,task_params)
-    if results.get('organic_description') and response['tasks'][0]['result']:
+    if response['tasks'][0]['result']:
+        results = get_results(response,tasks,task_params)
         organic_description = str([x.replace(",","") for x in results['organic_description']])
         organic_description = organic_description.replace("[","").replace("]","")
         df.loc[df["Keywords2"]== keyword,'seed_organic_description'] = str(organic_description)
     else:
+        print("Failed to get organic description")
         df.loc[df["Keywords2"]== keyword,'seed_organic_description'] =  keyword
 
 all_keywords = df["Keywords"].unique().tolist()
 for keyword in all_keywords:
     print(keyword)
     response = make_live_request(keyword,email,api_key,depth=5)
-    results = get_results(response,tasks,task_params)
-    if results.get('organic_description') and response['tasks'][0]['result']:
+    if response['tasks'][0]['result']:
+        results = get_results(response,tasks,task_params)
         organic_description = str([x.replace(",","") for x in results['organic_description']])
         organic_description = organic_description.replace("[","").replace("]","")
         df.loc[df["Keywords"]== keyword,'organic_description'] = organic_description
     else:
+        print("Failed to get organic description")
         df.loc[df["Keywords"]== keyword,'organic_description'] = [keyword]  
 
 model = SentenceTransformer(similarity_model_path)
